@@ -1,13 +1,7 @@
 # Video::FourCC::Info
 #  Shows information about codecs specified as a Four Character Code
 #
-# $Id: Info.pm 7049 2009-05-12 18:44:11Z FREQUENCY@cpan.org $
-#
-# By Jonathan Yu <frequency@cpan.org>, 2009. All rights reversed.
-#
-# This package and its contents are released by the author into the
-# Public Domain, to the full extent permissible by law. For additional
-# information, please see the included `LICENSE' file.
+# $Id: Info.pm 8227 2009-07-26 00:31:20Z FREQUENCY@cpan.org $
 
 package Video::FourCC::Info;
 
@@ -46,15 +40,15 @@ my $dbh = DBI->connect(
 
 =head1 NAME
 
-Video::FourCC::Info - Find information about codecs from its FourCC
+Video::FourCC::Info - Perl module to retrieve information about FourCCs
 
 =head1 VERSION
 
-Version 1.1.5 ($Id: Info.pm 7049 2009-05-12 18:44:11Z FREQUENCY@cpan.org $)
+Version 1.1.7 ($Id: Info.pm 8227 2009-07-26 00:31:20Z FREQUENCY@cpan.org $)
 
 =cut
 
-use version; our $VERSION = qv('1.1.5');
+use version; our $VERSION = qv('1.1.7');
 
 =head1 DESCRIPTION
 
@@ -289,9 +283,9 @@ Your name here ;-)
 
 =over
 
-=item * Thanks to Allen Day E<lt>allenday@ucla.eduE<gt> and Benjamin R. Ginter
-E<lt>bginter@asicommunications.comE<gt>, developers of Video::Info, which
-inspired the creation of this module.
+=item * Thanks to Allen Day E<lt>allenday@ucla.eduE<gt> and Benjamin R.
+Ginter E<lt>bginter@asicommunications.comE<gt>, developers of Video::Info,
+which inspired the creation of this module.
 
 =back
 
@@ -367,28 +361,19 @@ L<http://msdn.microsoft.com/en-us/library/ms867195.aspx#fourcccodes>
 
 =head1 LICENSE
 
-Copyleft 2009 by Jonathan Yu <frequency@cpan.org>. All rights reversed.
-
-I, the copyright holder of this package, hereby release the entire contents
-therein into the public domain. This applies worldwide, to the extent that
-it is permissible by law.
-
-In case this is not legally possible, I grant any entity the right to use
-this work for any purpose, without any conditions, unless such conditions
-are required by law.
-
-The full details of this can be found in the B<LICENSE> file included in
-this package.
+In a perfect world, I could just say that this package and all of the code
+it contains is Public Domain. It's a bit more complicated than that; you'll
+have to read the included F<LICENSE> file to get the full details.
 
 =head1 DISCLAIMER OF WARRANTY
 
 The software is provided "AS IS", without warranty of any kind, express or
 implied, including but not limited to the warranties of merchantability,
-fitness for a particular purpose and noninfringement. In no event shall the
-authors or copyright holders be liable for any claim, damages or other
-liability, whether in an action of contract, tort or otherwise, arising from,
-out of or in connection with the software or the use or other dealings in
-the software.
+fitness for a particular purpose and noninfringement. In no event shall
+the authors or copyright holders be liable for any claim, damages or other
+liability, whether in an action of contract, tort or otherwise, arising
+from, out of or in connection with the software or the use or other dealings
+in the software.
 
 =cut
 
